/// <reference types="react" />
import { ReactNode } from 'react';
export { Provider as EthersProvider } from '@ethersproject/abstract-provider';
import * as _ethersproject_providers from '@ethersproject/providers';
export { JsonRpcProvider } from '@ethersproject/providers';
import * as _web3_react_types from '@web3-react/types';
import { Connector } from '@web3-react/types';
export { Provider as Eip1193Provider } from '@web3-react/types';
import { Web3ReactHooks } from '@web3-react/core';

declare const SUPPORTED_LOCALES: string[];
declare type SupportedLocale = typeof SUPPORTED_LOCALES[number] | 'pseudo';
declare const DEFAULT_LOCALE: SupportedLocale;

interface Colors {
    accent: string;
    container: string;
    module: string;
    interactive: string;
    outline: string;
    dialog: string;
    primary: string;
    onAccent: string;
    secondary: string;
    hint: string;
    onInteractive: string;
    active: string;
    success: string;
    warning: string;
    error: string;
    currentColor: 'currentColor';
}
interface Attributes {
    borderRadius: boolean | number;
    fontFamily: string | {
        font: string;
        variable: string;
    };
    fontFamilyCode: string;
}
interface Theme extends Partial<Attributes>, Partial<Colors> {
}

declare type Web3ProvderProps = {
    theme?: Theme;
    locale?: SupportedLocale;
    children: ReactNode;
};

declare type ConnectWalletProps = {
    visible: boolean;
    close: () => void;
};
declare function ConnectWallet(props: ConnectWalletProps): JSX.Element;

declare type SwitchChainProps = {
    visible: boolean;
    close: () => void;
    chainIds?: number[];
};
declare function SwitchChain(props: SwitchChainProps): JSX.Element;

declare enum ConnectionType {
    INJECTED = "INJECTED",
    COINBASE_WALLET = "COINBASE_WALLET",
    WALLET_CONNECT = "WALLET_CONNECT"
}
interface Connection {
    connector: Connector;
    hooks: Web3ReactHooks;
    type: ConnectionType;
    name?: string;
    icon?: string;
}
declare const connections: {
    [key in ConnectionType]: Connection;
};

/**
 * List of all the networks supported by the Uniswap Interface
 */
declare enum SupportedChainId {
    MAINNET = 1,
    ROPSTEN = 3,
    RINKEBY = 4,
    GOERLI = 5,
    BSC = 97,
    BSC_TESTNET = 56,
    FTM = 250,
    FTM_TESTNET = 4002,
    ARBITRUM_ONE = 42161,
    ARBITRUM_RINKEBY = 421611,
    OPTIMISM = 10,
    OPTIMISTIC_KOVAN = 69,
    POLYGON = 137,
    POLYGON_MUMBAI = 80001
}
declare enum ChainName {
    MAINNET = "mainnet",
    ROPSTEN = "ropsten",
    RINKEBY = "rinkeby",
    GOERLI = "goerli",
    BSC = "bsc",
    BSC_TESTNET = "bsc-testnet",
    FTM = "fantom",
    FTM_TESTNET = "fantom-testnet",
    OPTIMISM = "optimism-mainnet",
    OPTIMISTIC_KOVAN = "optimism-kovan",
    ARBITRUM_ONE = "arbitrum-mainnet",
    ARBITRUM_RINKEBY = "arbitrum-rinkeby",
    POLYGON = "polygon-mainnet",
    POLYGON_MUMBAI = "polygon-mumbai"
}

declare function getIsInjected(): boolean;
declare function getIsMetaMask(): boolean;
declare function getIsCoinbaseWallet(): boolean;
declare function getConnection(c: Connector | ConnectionType): Connection;
declare function getConnectionName(connectionType: ConnectionType, isMetaMask?: boolean): "MetaMask" | "Injected" | "Coinbase Wallet" | "WalletConnect";
declare function isChainAllowed(connector: Connector, chainId: number): boolean;
declare const switchChain: (connector: Connector, chainId: SupportedChainId, account?: string) => Promise<void>;

interface BaseChainInfo {
    readonly blockWaitMsBeforeWarning?: number;
    readonly explorer: string;
    readonly logoUrl: string;
    readonly label: string;
    readonly helpCenterUrl?: string;
    readonly nativeCurrency: {
        name: string;
        symbol: string;
        decimals: number;
    };
}
declare function getChainInfo(chainId: SupportedChainId | number | undefined): BaseChainInfo;
declare function getChainInfoOrDefault(chainId: number | undefined): BaseChainInfo;

declare function useWeb3Provider(): {
    connectProvider: (conntionType: ConnectionType) => Promise<boolean>;
    switchChain: (chainId: number) => Promise<boolean | undefined>;
    connector: _web3_react_types.Connector;
    chainId: number | undefined;
    accounts: string[] | undefined;
    isActivating: boolean;
    account: string | undefined;
    isActive: boolean;
    provider: _ethersproject_providers.Web3Provider | undefined;
    ENSNames: undefined[] | (string | null)[];
    ENSName: string | null | undefined;
    hooks: {
        useSelectedStore: (connector: _web3_react_types.Connector) => _web3_react_types.Web3ReactStore;
        useSelectedChainId: (connector: _web3_react_types.Connector) => number | undefined;
        useSelectedAccounts: (connector: _web3_react_types.Connector) => string[] | undefined;
        useSelectedIsActivating: (connector: _web3_react_types.Connector) => boolean;
        useSelectedAccount: (connector: _web3_react_types.Connector) => string | undefined;
        useSelectedIsActive: (connector: _web3_react_types.Connector) => boolean;
        useSelectedProvider: <T extends _ethersproject_providers.BaseProvider = _ethersproject_providers.Web3Provider>(connector: _web3_react_types.Connector, network?: _ethersproject_providers.Networkish | undefined) => T | undefined;
        useSelectedENSNames: (connector: _web3_react_types.Connector, provider?: _ethersproject_providers.BaseProvider | undefined) => undefined[] | (string | null)[];
        useSelectedENSName: (connector: _web3_react_types.Connector, provider?: _ethersproject_providers.BaseProvider | undefined) => string | null | undefined;
        usePriorityConnector: () => _web3_react_types.Connector;
        usePriorityStore: () => _web3_react_types.Web3ReactStore;
        usePriorityChainId: () => number | undefined;
        usePriorityAccounts: () => string[] | undefined;
        usePriorityIsActivating: () => boolean;
        usePriorityAccount: () => string | undefined;
        usePriorityIsActive: () => boolean;
        usePriorityProvider: <T_1 extends _ethersproject_providers.BaseProvider = _ethersproject_providers.Web3Provider>(network?: _ethersproject_providers.Networkish | undefined) => T_1 | undefined;
        usePriorityENSNames: (provider?: _ethersproject_providers.BaseProvider | undefined) => undefined[] | (string | null)[];
        usePriorityENSName: (provider?: _ethersproject_providers.BaseProvider | undefined) => string | null | undefined;
    };
};

declare function Web3ProviderWidget(props: Web3ProvderProps): JSX.Element;

export { BaseChainInfo, ChainName, ConnectWallet, Connection, ConnectionType, DEFAULT_LOCALE, SUPPORTED_LOCALES, SupportedChainId, SupportedLocale, SwitchChain, Web3ProviderWidget, connections, getChainInfo, getChainInfoOrDefault, getConnection, getConnectionName, getIsCoinbaseWallet, getIsInjected, getIsMetaMask, isChainAllowed, switchChain, useWeb3Provider };
